#!/bin/bash -e
# Copyright (c) 2013 The Chromium OS Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

cd "${0%/*}"

case $1 in
-h|--help)
  echo "Usage: $0 [rev]"
  exit 0
  ;;
esac

rev=${1:-0}
if [[ $# -gt 1 || -n ${1//[0-9]} ]] ; then
  cat <<-EOF
Usage: makedist.sh <rev>

The ver will be taken from manifest.json.

The rev should be an integer.

Example:
 ./makedist.sh 1
This will generate a manifest for version 3.0.1 (when version is '3.0'
in the manifest.json file)
EOF
  exit 0
fi

json_value() {
  local key=$1
  sed -n -r \
    -e '/^[[:space:]]*"'"${key}"'"/s|.*:[[:space:]]*"([^"]*)",?$|\1|p' \
    manifest.json
}

PN=$(json_value name | sed 's:[[:space:]/]:_:g' | tr '[:upper:]' '[:lower:]')
if [[ ${PN} == "__msg_name__" ]] ; then
  PN=$(basename "$(pwd)")
fi
PV=$(json_value version)
PVR="${PV}.${rev}"
P="${PN}-${PVR}"

rm -rf "${P}"
mkdir "${P}"

while read line ; do
  [[ ${line} == */* ]] && mkdir -p "${P}/${line%/*}"
  ln "${line}" "${P}/${line}"
done < <(sed 's:#.*::' manifest.files)
cp Makefile manifest.files manifest.json "${P}/"

make -C "${P}" -j min
while read line ; do
  mv -v "${line}" "${line%.min}"
done < <(find "${P}" -name '*.min')
rm "${P}"/{manifest.files,Makefile}

sed -i \
  -e '/"version"/s:"[^"]*",:"'${PVR}'",:' \
  "${P}/manifest.json"

zip="${P}.zip"
rm -f "${zip}"
zip -r "${zip}" "${P}"
rm -rf "${P}"
du -b "${zip}"
